<?php

namespace Drupal\pf_onesignal\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Endpoint to receive OneSignal apple id validation.
 */
class AppleId extends ControllerBase {

  /**
   * The onesignal configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $config;

  /**
   * AppleId constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('pf_onesignal.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): AppleId {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Creates the JSON response for this controller.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function execute(): JsonResponse {
    return new JsonResponse([
      'applinks' => [
        'apps' => [],
        'details' => [
          [
            'appID' => $this->config->get('mobilebundleid'),
            'paths' => [
              '*',
            ],
          ],
        ],
      ],
    ]);
  }

}
